@@ -5,14 +5,9 @@ import re
 import os
 import sys
 import struct
-import logging
 import platform
 import threading
-import traceback
 
-from socket import AF_INET
-from socket import inet_pton
-from socket import inet_ntop
 from socket import inet_aton
 
 try:
@@ -68,45 +63,6 @@ rate_suffixes = {'bit': 1,
                  'TBps': 8000000000000}
 
 
-##
-# Debug
-#
-_log_configured = False
-
-
-def debug(f):
-    '''
-    Debug decorator, that logs all the function calls
-    '''
-    if os.environ.get('DEBUG', None) is None:
-        return f
-
-    global _log_configured
-    # some nosetests bug prevents the rest of this function
-    # being marked as "covered", despite it really IS; so
-    # FIXME: trace and file nosetests bug
-    # possibly related to the log capture
-    if not _log_configured:
-        _log_configured = True
-        filename = os.environ.get('DEBUG_FILE', None)
-        logging.basicConfig(filename=filename,
-                            level=logging.DEBUG)
-
-    def wrap(*argv, **kwarg):
-        tid = id(threading.current_thread())
-        bt = ''.join(traceback.format_stack()[:-1])
-        logging.debug("%s %s: bt: %s" % (tid, f.__name__, bt))
-        logging.debug("%s %s: call: %s; %s" % (tid,
-                                               f.__name__,
-                                               argv,
-                                               kwarg))
-        ret = f(*argv, **kwarg)
-        logging.debug("%s %s: ret: %s" % (tid, f.__name__, ret))
-        return ret
-
-    return wrap
-
-
 ##
 # General purpose
 #
@@ -180,21 +136,6 @@ def map_namespace(prefix, ns):
     return (by_name, by_value)
 
 
-def list_subnet(dqn, mask, family=AF_INET):
-    '''
-    List all IPs in the network
-    '''
-    if family != AF_INET:
-        raise NotImplementedError('please report the issue')
-
-    ret = []
-    net = struct.unpack('>I', inet_pton(family, dqn))[0]
-    shift = 32 - mask
-    for host in range(1, 2 ** shift):
-        ret.append(inet_ntop(family, struct.pack('>I', net | host)))
-    return ret
-
-
 def dqn2int(mask):
     '''
     IPv4 dotted quad notation to int mask conversion
