@@ -3,24 +3,28 @@ Netlink proxy engine
 '''
 import errno
 import struct
+import logging
+import traceback
 import threading
 
 
-class NetlinkInProxy(object):
+class NetlinkProxy(object):
     '''
-    Incoming proxy::
+    Proxy schemes::
 
-        User -> NetlinkInProxy -> Kernel
+        User -> NetlinkProxy -> Kernel
                        |
              <---------+
 
+        User <- NetlinkProxy <- Kernel
+
     '''
 
-    def __init__(self, rcvch, bypass=None, lock=None):
-        self.rcvch = rcvch
-        self.bypass = bypass
+    def __init__(self, policy='forward', nl=None, lock=None):
+        self.nl = nl
         self.lock = lock or threading.Lock()
         self.pmap = {}
+        self.policy = policy
 
     def handle(self, data):
         #
@@ -31,15 +35,22 @@ class NetlinkInProxy(object):
         if plugin is not None:
             with self.lock:
                 try:
-                    if plugin(data, self.rcvch, self.bypass) is None:
-                        msg = struct.pack('IHH', 20, 2, 0)
+                    ret = plugin(data, self.nl)
+                    if ret is None:
+                        msg = struct.pack('IHH', 40, 2, 0)
                         msg += data[8:16]
                         msg += struct.pack('I', 0)
-                        self.rcvch.send(msg)
+                        # nlmsgerr struct alignment
+                        msg += b'\0' * 20
+                        return {'verdict': self.policy,
+                                'data': msg}
+                    else:
+                        return ret
 
                 except Exception as e:
+                    logging.error(traceback.format_exc())
                     # errmsg
-                    if isinstance(e, OSError):
+                    if isinstance(e, (OSError, IOError)):
                         code = e.errno
                     else:
                         code = errno.ECOMM
@@ -48,6 +59,6 @@ class NetlinkInProxy(object):
                     msg += struct.pack('I', code)
                     msg += data
                     msg = struct.pack('I', len(msg) + 4) + msg
-                    self.rcvch.send(msg)
-                return True
-        return False
+                    return {'verdict': 'error',
+                            'data': msg}
+        return None
